diff lisp/modes/follow.el @ 70:131b0175ea99 r20-0b30

Import from CVS: tag r20-0b30
author cvs
date Mon, 13 Aug 2007 09:02:59 +0200
parents ec9a17fef872
children 360340f9fd5f
line wrap: on
line diff
--- a/lisp/modes/follow.el	Mon Aug 13 09:00:04 2007 +0200
+++ b/lisp/modes/follow.el	Mon Aug 13 09:02:59 2007 +0200
@@ -49,7 +49,7 @@
 ;; side-by-side window are used. The user can, with the help of Follow
 ;; mode, use two full-height windows as though they would have been
 ;; one. Imagine yourself editing a large function, or section of text,
 ;; and being able to use 144 lines instead of the normal 72... (your
 ;; mileage may vary).
 
 ;; The latest version, and a demonstration, are avaiable at:
@@ -734,7 +734,7 @@
 side-by-side window are used. The user can, with the help of Follow
 mode, use two full-height windows as though they would have been
 one. Imagine yourself editing a large function, or section of text,
-and being able to use 144 lines instead of the normal 72... (your
+and beeing able to use 144 lines instead of the normal 72... (your
 mileage may vary).
 
 To split one large window into two side-by-side windows, the commands
@@ -2345,8 +2345,8 @@
 ;;; called from other places, e.g. `post-command-hook' and
 ;;; `post-command-idle-hook'.
 
 ;; If this function is called it is too late for this window, but
 ;; we might save other windows from being recentered.
 
 (if (and follow-avoid-tail-recenter-p (boundp 'window-scroll-functions))
     (add-hook 'window-scroll-functions 'follow-avoid-tail-recenter t))
@@ -49,7 +49,7 @@
 ;; mode, use two full-height windows as though they would have been
 ;; one. Imagine yourself editing a large function, or section of text,
-;; and being able to use 144 lines instead of the normal 72... (your
+;; and beeing able to use 144 lines instead of the normal 72... (your
 ;; mileage may vary).
 
@@ -2345,8 +2345,8 @@
 ;;; `post-command-idle-hook'.
 
-;; If this function is called it is too late for this window, but
-;; we might save other windows from being recentered.
+;; If this function is called it is to late for this window, but
+;; we might save other windows from beeing recentered.
 
 (if (and follow-avoid-tail-recenter-p (boundp 'window-scroll-functions))